import React, { useState, useEffect } from 'react';
import { Mic, MicOff } from 'lucide-react';

interface UserData {
  name: string;
  email: string;
}

function App() {
  const [userData, setUserData] = useState<UserData>({
    name: '',
    email: '',
  });
  const [step, setStep] = useState<'welcome' | 'name' | 'email' | 'complete'>('welcome');
  const [isListening, setIsListening] = useState(false);
  const [message, setMessage] = useState('');

  // Initialize speech synthesis and recognition
  const speak = (text: string) => {
    const utterance = new SpeechSynthesisUtterance(text);
    window.speechSynthesis.speak(utterance);
  };

  const startListening = () => {
    if ('webkitSpeechRecognition' in window) {
      const recognition = new (window as any).webkitSpeechRecognition();
      recognition.continuous = false;
      recognition.interimResults = false;

      recognition.onstart = () => {
        setIsListening(true);
      };

      recognition.onresult = (event: any) => {
        const transcript = event.results[0][0].transcript;
        handleVoiceInput(transcript);
      };

      recognition.onerror = (event: any) => {
        console.error('Speech recognition error:', event.error);
        setIsListening(false);
      };

      recognition.onend = () => {
        setIsListening(false);
      };

      recognition.start();
    } else {
      alert('Speech recognition is not supported in your browser.');
    }
  };

  const handleVoiceInput = (transcript: string) => {
    if (step === 'name') {
      setUserData(prev => ({ ...prev, name: transcript }));
      setStep('email');
    } else if (step === 'email') {
      setUserData(prev => ({ ...prev, email: transcript.toLowerCase().replace(/\s+/g, '') }));
      setStep('complete');
    }
  };

  useEffect(() => {
    // Initial welcome message
    if (step === 'welcome') {
      setTimeout(() => {
        speak('Welcome to Biryani Hub');
        setTimeout(() => {
          setStep('name');
        }, 2000);
      }, 1000);
    }

    // Name prompt
    if (step === 'name') {
      setMessage('Please tell me your name');
      speak('Tell me your name');
    }

    // Email prompt
    if (step === 'email') {
      setMessage('Please provide your email address');
      speak('Please provide your email address');
    }

    // Completion
    if (step === 'complete') {
      setMessage(`Thank you ${userData.name}! Your email ${userData.email} has been registered.`);
      speak(`Thank you ${userData.name}! Your email has been registered.`);
    }
  }, [step, userData.name]);

  return (
    <div className="min-h-screen bg-gradient-to-br from-orange-100 to-amber-50 flex items-center justify-center p-4">
      <div className="bg-white rounded-xl shadow-xl p-8 max-w-md w-full">
        <h1 className="text-3xl font-bold text-orange-600 mb-6 text-center">
          Biryani Hub
        </h1>
        
        <div className="space-y-6">
          <div className="text-center text-lg font-medium text-gray-700">
            {message}
          </div>

          {(step === 'name' || step === 'email') && (
            <button
              onClick={startListening}
              className={`w-full py-3 px-4 rounded-lg flex items-center justify-center gap-2 ${
                isListening 
                  ? 'bg-red-500 hover:bg-red-600' 
                  : 'bg-orange-500 hover:bg-orange-600'
              } text-white transition-colors`}
            >
              {isListening ? (
                <>
                  <MicOff className="w-5 h-5" />
                  Listening...
                </>
              ) : (
                <>
                  <Mic className="w-5 h-5" />
                  Click to Speak
                </>
              )}
            </button>
          )}

          {userData.name && (
            <div className="bg-gray-50 rounded-lg p-4">
              <p className="text-gray-700">
                <span className="font-medium">Name:</span> {userData.name}
              </p>
              {userData.email && (
                <p className="text-gray-700">
                  <span className="font-medium">Email:</span> {userData.email}
                </p>
              )}
            </div>
          )}
        </div>
      </div>
    </div>
  );
}

export default App;